package com.biganto.visual.roompark.presentation.screen.settings

import android.view.View
import android.widget.ImageView
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import butterknife.BindView
import com.biganto.visual.roompark.R
import com.biganto.visual.roompark.base.RoomParkApplication
import com.biganto.visual.roompark.base.RoomParkMainActivity
import com.biganto.visual.roompark.conductor.BigantoBaseController
import com.biganto.visual.roompark.presentation.screen.settings.util.PushListAdapter
import com.google.android.material.textview.MaterialTextView
import timber.log.Timber
import javax.inject.Inject

/**
 * Created by Vladislav Bogdashkin on 30.09.2019.
 */

class SettingsScreenController :
    BigantoBaseController<SettingsScreenViewState
        , SettingsScreen
        , SettingsScreenPresenter>()
    , SettingsScreen {

    override fun injectDependencies() {
        getComponent()
    }

    @Inject
    override lateinit var injectedPresenter: SettingsScreenPresenter

    @BindView(R.id.pushRecyclerView)
    lateinit var pushRecycler:RecyclerView

    @BindView(R.id.cachedRecyclerView)
    lateinit var cachedRecycler:RecyclerView

    @BindView(R.id.downloadToursText)
    lateinit var toursDownloaderTitle:MaterialTextView

    @BindView(R.id.downloadFlatCardsText)
    lateinit var flatDownloaderTitle:MaterialTextView

    @BindView(R.id.downloadToursIcon)
    lateinit var toursDownloaderButton:ImageView

    @BindView(R.id.downloadFlatCardsIcon)
    lateinit var flatDownloaderButton:ImageView



    override fun onViewBound(v: View) {

        pushRecycler.isNestedScrollingEnabled = true
        pushRecycler.layoutManager =
            LinearLayoutManager(activity, RecyclerView.VERTICAL, false)
        pushRecycler.adapter = PushListAdapter()
        pushRecycler.itemAnimator = null
    }

    override fun render(viewState: SettingsScreenViewState) {
        super.render(viewState)
        Timber.d("Render state $viewState")
        when(viewState){
            is SettingsScreenViewState.Idle -> render(viewState)
            is SettingsScreenViewState.LoadSettingsList -> render(viewState)
        }
    }

    private fun render(viewState: SettingsScreenViewState.Idle){

    }


    private fun render(viewState: SettingsScreenViewState.LoadSettingsList){
        (pushRecycler.adapter as PushListAdapter).setItems(viewState.settings.pushItems)
    }

    private fun getComponent() = DaggerSettingsScreenComponent.factory()
        .create(RoomParkApplication.component,activity as RoomParkMainActivity)
        .inject(this)

    override fun getLayoutId(): Int = R.layout.settings_screen

}